

Ext.define('PO.tsweekly.HourWeeklyProxy', {
    extend: 'Ext.data.proxy.Client',
    alias: 'proxy.hourWeeklyProxy',

    debug: true,

    constructor: function(config) {
        this.callParent(arguments);
    },


    /**
     * Fake processing function to commit the records, set the current operation
     * to successful and call the callback if provided. This function is shared
     * by the create, update and destroy methods to perform the bare minimum
     * processing required for the proxy to register a result from the action.
     */
    updateOperation: function(operation, callback, scope) {
        var i = 0,
            recs = operation.getRecords(),
            len = recs.length;
            
        for (i; i < len; i++) {
            recs[i].commit();
        }
        operation.setCompleted();
        operation.setSuccessful();
        
        Ext.callback(callback, scope || this, [operation]);
    },


    
    //inherit docs
    create: function(operation, callback, scope) {
	var me = this;
	if (me.debug) { console.log('HourWeeklyProxy.create: Started'); console.log(operation); }

	this.updateOperation.apply(this, arguments);

	if (me.debug) console.log('HourWeeklyProxy.create: Finished');
    },


    //inherit docs
    read: function(operation, callback, scope) {
	var me = this;
	if (me.debug) { console.log('HourWeeklyProxy.read: Started'); console.log(operation); }
        operation.setStarted();

        var data = [
            { data: { name: 'File1', thumbnail: '/piko/desktop/img/my_photos.png', url: '/img/faces.jpg', size: 32000, metadata: { type: 'file', width: 64, height: 64 }},
                join: function(store) { this.store = store; },
                unjoin: function(store) { this.store = store; }},
//            { data: { name: 'File2', thumbnail: '/piko/desktop/img/my_photos.png', url: '/img/faces.jpg', size: 32000, metadata: { type: 'file', width: 64, height: 64 }}, join: function(store) { this.store = store; }},
        ];

        operation.resultSet = Ext.create('Ext.data.ResultSet', {
            records: data,
            total: data.length,
            loaded: true
        });

        operation.commitRecords(data);
        operation.setCompleted();
        operation.setSuccessful();

        if (typeof callback == 'function') {
            callback.call(scope || this, operation);
        }
	if (me.debug) console.log('HourWeeklyProxy.read: Finished');
    },

    //inherit docs
    update: function(operation, callback, scope) {
	var me = this;
	if (me.debug) { console.log('HourWeeklyProxy.update: Started'); console.log(operation); }

	this.updateOperation.apply(this, arguments);

	if (me.debug) console.log('HourWeeklyProxy.update: Finished');
    },


    //inherit
    destroy: function(operation, callback, scope) {
	var me = this;
	if (me.debug) { console.log('HourWeeklyProxy.destroy: Started'); console.log(operation); }

	this.updateOperation.apply(this, arguments);

	if (me.debug) console.log('HourWeeklyProxy.destroy: Finished');
    },


    clear: function() {
	var me = this;
	if (me.debug) { console.log('HourWeeklyProxy.clear: Started'); console.log(operation); }

	this.updateOperation.apply(this, arguments);

	if (me.debug) console.log('HourWeeklyProxy.clear: Finished');
    }
});


